"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var path = require("path");
var getFileDocumentation_1 = require("../getFileDocumentation");
describe('getFileDocumentation', function () {
    it('Should parse class-based components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/Column.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Column', c.name);
        chai_1.assert.equal('Form column.', c.comment);
        chai_1.assert.equal('Component', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IColumnProps', i.name);
        chai_1.assert.equal('Column properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should parse class-based components with unexported props interface', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/ColumnWithoutExportedProps.tsx'); // it's running in ./temp    
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Column', c.name);
        chai_1.assert.equal('Form column.', c.comment);
        chai_1.assert.equal('Component', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IColumnProps', i.name);
        chai_1.assert.equal('Column properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should parse functional components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/Row.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Row', c.name);
        chai_1.assert.equal('Form row.', c.comment);
        chai_1.assert.equal('StatelessComponent', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IRowProps', i.name);
        chai_1.assert.equal('Row properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should parse class-based pure components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/PureRow.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Row', c.name);
        chai_1.assert.equal('Form row.', c.comment);
        chai_1.assert.equal('PureComponent', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IRowProps', i.name);
        chai_1.assert.equal('Row properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should avoid parsing exported objects as components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/ConstExport.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Row', c.name);
        chai_1.assert.equal('Form row.', c.comment);
        chai_1.assert.equal('StatelessComponent', c.extends);
        chai_1.assert.isNotNull(c);
        var i = c.propInterface;
        chai_1.assert.equal('IRowProps', i.name);
        chai_1.assert.equal('Row properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should parse higher order components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/ColumnHigherOrderComponent.tsx'); // it's running in ./temp        
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(4, result.components.length);
        var r1 = result.components[0];
        chai_1.assert.equal('ColumnHighOrderComponent1', r1.name);
        chai_1.assert.equal('ColumnHighOrderComponent1 specific comment', r1.comment);
        chai_1.assert.equal('Column', r1.extends);
        chai_1.assert.isNotNull(r1.propInterface);
        var i = r1.propInterface;
        chai_1.assert.equal('IColumnProps', i.name);
        chai_1.assert.equal('Column properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
        var r2 = result.components[1];
        chai_1.assert.equal('ColumnHighOrderComponent2', r2.name);
        chai_1.assert.equal('Form column.', r2.comment);
        chai_1.assert.equal('Column', r2.extends);
        chai_1.assert.isNotNull(r2.propInterface);
    });
});
//# sourceMappingURL=getFileDocumentation.spec.js.map